adaptive library

Platform-adaptive wallet UI entrypoint.

Classes

AdaptiveWalletButton
Platform-adaptive connect button.
WalletAvatar
Renders Wallet Standard SVG and raster data URI icons.
WalletPickerContent
Framework-neutral, responsive wallet picker body.
WalletUiKeys
Stable keys for wallet UI automation and accessibility testing.
WalletUiPalette
Colors shared by the unopinionated picker content.
WalletUiTheme
Supplies wallet-specific design tokens below this widget.
WalletUiThemeData
Configurable geometry and copy shared by all wallet widgets.

Enums

WalletUiStyle
Explicit style override for adaptive wallet widgets.

Functions

compactWalletAddress(String address, {int edgeLength = 4}) String
Shortens address without assuming a particular alphabet.
defaultWalletUiStyle(TargetPlatform platform) WalletUiStyle
Returns the platform's conventional wallet UI style.
showAdaptiveWalletPicker({required BuildContext context, required WalletController controller, WalletEmptyBuilder? emptyBuilder, WalletPickerHeaderBuilder? headerBuilder, WalletUiStyle? style, WalletTileBuilder? tileBuilder}) Future<Wallet?>
Opens the Material or Cupertino picker for style or the current platform.

Typedefs

WalletButtonBuilder = Widget Function(BuildContext context, WalletAdapterState state, VoidCallback? onPressed)
Builds a complete connect or account button.
WalletEmptyBuilder = Widget Function(BuildContext context)
Builds an application-specific empty state.
WalletPickerHeaderBuilder = Widget Function(BuildContext context, String title, VoidCallback? onClose)
Builds application-specific picker header content.
WalletTileBuilder = Widget Function(BuildContext context, Wallet wallet, int index, VoidCallback onTap)
Builds an application-specific wallet row.